# Changelog

## 0.3.0 (2026-03-27)

Full Changelog: [v0.2.2...v0.3.0](https://github.com/VAT-Sense/vatsense-python/compare/v0.2.2...v0.3.0)

### Features

* **internal:** implement indices array format for query and form serialization ([f95a996](https://github.com/VAT-Sense/vatsense-python/commit/f95a996c18196d0de1fd9eea2a705918d479617d))


### Bug Fixes

* sanitize endpoint path params ([240c360](https://github.com/VAT-Sense/vatsense-python/commit/240c3603ff0990149757ba2a0b0f13f6f01ee242))


### Chores

* **ci:** skip lint on metadata-only changes ([a43372b](https://github.com/VAT-Sense/vatsense-python/commit/a43372b63309452fd5d028fa6ec22f268b6252c3))
* **internal:** update gitignore ([ecb215d](https://github.com/VAT-Sense/vatsense-python/commit/ecb215df4b173aa767b25f04968a6afd6092e5b0))


### Documentation

* **readme:** tailor README to VAT Sense use cases ([efd58d1](https://github.com/VAT-Sense/vatsense-python/commit/efd58d1bed64eebdddaa2559728e434cb676cf15))

## 0.2.2 (2026-03-18)

Full Changelog: [v0.2.1...v0.2.2](https://github.com/VAT-Sense/vatsense-python/compare/v0.2.1...v0.2.2)

### Chores

* update SDK settings ([8ee6952](https://github.com/VAT-Sense/vatsense-python/commit/8ee6952ae40fc24165317e057ccc19f9a92db82c))
* update SDK settings ([141680d](https://github.com/VAT-Sense/vatsense-python/commit/141680d92d4f5f1cc6c016c257f80f46b1a4f822))
* update SDK settings ([d35b17e](https://github.com/VAT-Sense/vatsense-python/commit/d35b17ecaac464c24b877e72f65eaef6fd9343bb))

## 0.2.1 (2026-03-18)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/VAT-Sense/vatsense-python/compare/v0.2.0...v0.2.1)

### Chores

* update SDK settings ([ce5ef4b](https://github.com/VAT-Sense/vatsense-python/commit/ce5ef4b64982a5ffaf1c4019a862025e0750bc06))
* update SDK settings ([c761829](https://github.com/VAT-Sense/vatsense-python/commit/c761829514d13b91993d33fa36714b4119fd62ad))
* update SDK settings ([1f51f88](https://github.com/VAT-Sense/vatsense-python/commit/1f51f88cfceb700e3f193b4dc4d2f8e98423c80c))

## 0.2.0 (2026-03-18)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/VAT-Sense/vatsense-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([6f2c500](https://github.com/VAT-Sense/vatsense-python/commit/6f2c500e84ac2842c06f22927c4a247f75c2aed0))

## 0.1.0 (2026-03-18)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/VAT-Sense/vatsense-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([25b4c32](https://github.com/VAT-Sense/vatsense-python/commit/25b4c32c42aee862ace266abe50365349aceb431))


### Chores

* update SDK settings ([5f02a50](https://github.com/VAT-Sense/vatsense-python/commit/5f02a5091af62c43c861061aa66a706588a24425))
* update SDK settings ([cca1b6b](https://github.com/VAT-Sense/vatsense-python/commit/cca1b6be03b5466f0b6170fdf0884577d3c574cd))
* update SDK settings ([a72583d](https://github.com/VAT-Sense/vatsense-python/commit/a72583dbaca3469d6f8c3281dbca3a4c9256ea28))
